<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'Heuliañ kemmoù an traoù stur',
	'revisions_slogan' => 'Heuliañ  kemmoù an traoù stur',
];
